==> ide-starter-squashed-232.8660.185-sources.jar: com/intellij/ide/customize/transferSettings/controllers/TransferSettingsController.kt <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.ide.customize.transferSettings.controllers

import com.intellij.ide.customize.transferSettings.models.BaseIdeVersion
import com.intellij.ide.customize.transferSettings.models.FailedIdeVersion
import com.intellij.ide.customize.transferSettings.models.IdeVersion
import com.intellij.ide.customize.transferSettings.models.Settings
import com.intellij.ide.customize.transferSettings.providers.DefaultImportPerformer
import com.intellij.ide.customize.transferSettings.providers.ImportPerformer
import com.intellij.openapi.progress.ProgressIndicator
import com.intellij.openapi.project.Project
import java.util.*

interface TransferSettingsController {
  fun itemSelected(ideVersion: BaseIdeVersion)

  fun performImport(project: Project?, ideVersion: IdeVersion, withPlugins: Boolean, pi: ProgressIndicator)
  fun performReload(ideVersion: FailedIdeVersion, pi: ProgressIndicator)

  fun addListener(listener: TransferSettingsListener)

  fun getImportPerformer(): ImportPerformer
}

interface TransferSettingsListener : EventListener {
  fun reloadPerformed(ideVersion: FailedIdeVersion) {}

  fun importStarted(ideVersion: IdeVersion, settings: Settings) {}
  fun importFailed(ideVersion: IdeVersion, settings: Settings, throwable: Throwable) {}
  fun importPerformed(ideVersion: IdeVersion, settings: Settings) {}

  fun itemSelected(ideVersion: BaseIdeVersion) {}
}

==> ide-starter-squashed-233.14015.106-sources.jar: com/intellij/ide/customize/transferSettings/controllers/TransferSettingsController.kt <==
// Copyright 2000-2023 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.ide.customize.transferSettings.controllers

import com.intellij.ide.customize.transferSettings.models.BaseIdeVersion
import com.intellij.ide.customize.transferSettings.models.FailedIdeVersion
import com.intellij.ide.customize.transferSettings.models.IdeVersion
import com.intellij.ide.customize.transferSettings.models.Settings
import com.intellij.ide.customize.transferSettings.providers.ImportPerformer
import com.intellij.ide.customize.transferSettings.providers.TransferSettingsPerformContext
import com.intellij.openapi.progress.ProgressIndicator
import com.intellij.openapi.project.Project
import java.util.*

interface TransferSettingsController {
  fun updateCheckboxes(ideVersion: IdeVersion)
  fun itemSelected(ideVersion: BaseIdeVersion)

  fun performImport(project: Project?, ideVersion: IdeVersion, pi: ProgressIndicator)
  fun performReload(ideVersion: FailedIdeVersion, pi: ProgressIndicator)

  fun addListener(listener: TransferSettingsListener)

  fun getImportPerformer(): ImportPerformer
}

interface TransferSettingsListener : EventListener {
  fun checkboxesUpdated(ideVersion: IdeVersion) {}

  fun reloadPerformed(ideVersion: FailedIdeVersion) {}

  fun importStarted(ideVersion: IdeVersion, settings: Settings) {}
  fun importFailed(ideVersion: IdeVersion, settings: Settings, throwable: Throwable) {}
  fun importPerformed(ideVersion: IdeVersion, settings: Settings, context: TransferSettingsPerformContext) {}

  fun itemSelected(ideVersion: BaseIdeVersion) {}
}
